@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,6 +10,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     George Suaridze <suag@1c.ru> (1C-Soft LLC) - Bug 560168
  *******************************************************************************/
 package org.eclipse.help.ui.internal;
 
@@ -409,10 +410,7 @@ public class ContextHelpDialog {
 										.toString());
 			}
 		} catch (Throwable e) {
-			HelpUIPlugin
-					.logError(
-							"An error occurred when opening context-sensitive help pop-up.", //$NON-NLS-1$
-							e);
+			Platform.getLog(getClass()).error("An error occurred when opening context-sensitive help pop-up.", e); //$NON-NLS-1$
 		}
 	}
 
@@ -475,7 +473,7 @@ public class ContextHelpDialog {
 		});
 	}
 
-	public class Description extends StyledText {
+	public static class Description extends StyledText {
 		/**
 		 * @param parent
 		 * @param style
