@@ -13,6 +13,7 @@
  *******************************************************************************/
 package org.eclipse.ui.internal.cheatsheets.registry;
 
+import java.text.Collator;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.Iterator;
@@ -31,15 +32,13 @@ import org.eclipse.ui.internal.cheatsheets.CheatSheetPlugin;
 import org.eclipse.ui.internal.cheatsheets.ICheatSheetResource;
 import org.eclipse.ui.internal.cheatsheets.Messages;
 
-import com.ibm.icu.text.Collator;
-
 /**
  *  Instances access the registry that is provided at creation time
  *  in order to determine the contained CheatSheet Contents
  */
 public class CheatSheetRegistryReader extends RegistryReader implements IRegistryChangeListener {
 
-	private class CategoryNode {
+	private static class CategoryNode {
 		private Category category;
 		private String path;
 		public CategoryNode(Category cat) {
@@ -64,7 +63,7 @@ public class CheatSheetRegistryReader extends RegistryReader implements IRegistr
 	/**
 	 * Represents a taskEditor entry in the registry
 	 */
-	public class TaskEditorNode {
+	public static class TaskEditorNode {
 		private String className;
 		private String iconPath;
 		private String id;
@@ -98,7 +97,7 @@ public class CheatSheetRegistryReader extends RegistryReader implements IRegistr
 	/**
 	 * Represents a taskExplorer entry in the registry
 	 */
-	public class TaskExplorerNode {
+	public static class TaskExplorerNode {
 		private String className;
 		private String iconPath;
 		private String name;
